@@ -1,4 +1,7 @@
 setMethodS3("extractDataForSegmentation", "RawGenomicSignals", function(this, order=TRUE, useWeights=TRUE, dropNonFinite=TRUE, dropZeroWeights=TRUE, dropWeightsIfAllEqual=TRUE, defaultChromosome=0L, defaultSampleName="Unnamed sample", ..., verbose=FALSE) {
+  # This is a single-chromosome method. Assert that is the case.
+  assertOneChromosome(this);
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -11,53 +14,73 @@ setMethodS3("extractDataForSegmentation", "RawGenomicSignals", function(this, or
 
   verbose && enter(verbose, "Extracting data used by segmentation algorithms");
 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Drop loci with unknown locations?
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  verbose && enter(verbose, "Dropping loci with unknown locations");
+  x <- this$x;
+  keep <- whichVector(is.finite(x));
+  nbrOfDropped <- length(x)-length(keep);
+  verbose && cat(verbose, "Number of dropped loci: ", nbrOfDropped);
+  if (nbrOfDropped > 0) {
+    this <- this[keep,,drop=FALSE];
+  }
+  rm(x, keep);
+  verbose && exit(verbose);
+
+
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Order along genome?
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  if (order) {
+    verbose && enter(verbose, "Ordering along genome");
+    this <- sort(this);
+    verbose && exit(verbose);
+  }
+
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Retrieving data
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  sampleName <- this$fullname;
+  sampleName <- getBasicField(this, "fullname");
+  if (is.null(sampleName)) {
+    sampleName <- getFullName(this);
+  }
   if (is.null(sampleName)) {
     sampleName <- defaultSampleName;
   }
 
   chromosome <- as.integer(this$chromosome);
-  if (is.na(chromosome)) {
+  if (all(is.na(chromosome))) {
     chromosome <- defaultChromosome;
   }
   nbrOfLoci <- nbrOfLoci(this);
   verbose && cat(verbose, "Sample name: ", sampleName);
-  verbose && cat(verbose, "Chromosome: ", chromosome);
+  verbose && cat(verbose, "Chromosomes: ", hpaste(sort(unique(chromosome))));
   verbose && cat(verbose, "Number of loci: ", nbrOfLoci);
 
   # Extracting data of interest
   data <- as.data.frame(this, translate=FALSE);
-  data <- cbind(chromosome=chromosome, data);
+  if (!is.element("chromosome", colnames(data))) {
+    data <- cbind(chromosome=chromosome, data);
+  }
 #  verbose && str(verbose, data);
 
   # Use weights, if they exists?
   hasWeights <- useWeights && (length(data$w) > 0);
   
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Drop loci with unknown locations?
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Dropping loci with unknown locations");
-  keep <- whichVector(is.finite(data$x));
-  nbrOfDropped <- nbrOfLoci-length(keep);
-  verbose && cat(verbose, "Number of dropped loci: ", nbrOfDropped);
-  if (nbrOfDropped > 0) {
-    data <- data[keep,,drop=FALSE];
-    nbrOfLoci <- nrow(data);
-#    verbose && str(verbose, data);
-  }
-  rm(keep);
-  verbose && exit(verbose);
-
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Drop non-finite signals?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (dropNonFinite) {
     verbose && enter(verbose, "Dropping loci with non-finite signals");
-    keep <- whichVector(is.finite(data$y));
+    y <- data$y;
+    verbose && cat(verbose, "Signals:");
+    verbose && str(verbose, y);
+    # Sanity check
+    stopifnot(is.numeric(y));
+    keep <- whichVector(is.finite(y));
     nbrOfDropped <- nbrOfLoci-length(keep);
     verbose && cat(verbose, "Number of dropped loci: ", nbrOfDropped);
     if (nbrOfDropped > 0) {
@@ -69,20 +92,6 @@ setMethodS3("extractDataForSegmentation", "RawGenomicSignals", function(this, or
     verbose && exit(verbose);
   }
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Order along genome?
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  if (order) {
-    verbose && enter(verbose, "Order data along genome");
-    # Order signals by their genomic location
-    o <- order(data$x);
-    data <- data[o,,drop=FALSE];
-#    verbose && str(verbose, data);
-    verbose && exit(verbose);
-    rm(o);
-  }
-
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Weights
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
