@@ -55,6 +55,10 @@ setMethodS3("segmentByMPCBS", "RawGenomicSignals", function(this, ..., cache=FAL
 
 
   verbose && enter(verbose, "Segmenting");
+  verbose && cat(verbose, "Chromosomes: ", hpaste(getChromosomes(this)));
+
+  # This is a single-chromosome method. Assert that is the case.
+  assertOneChromosome(this);
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Retrieving segmentation function
