@@ -1,9 +1,37 @@
+// alert("ChromosomeExplorer...");
 /****************************************************************
  * ChromosomeExplorer()
  *
  * Author: Henrik Bengtsson, hb@stat.berkeley.edu
  ****************************************************************/
 function ChromosomeExplorer() {
+  var chromosomes = new Array('01','02','03','04','05','06','07','08','09','10','11','12','13','14','15','16','17','18','19','20','21','22','X');
+  var chipTypes = null;
+
+  var nav = null;
+  var navArea = null;
+  var navAreaWidth = 0;
+  var navAreaX = 0;
+  var navImage = null;
+  var navImageOffsetX = 0;
+  var navImageWidth = 0;
+  var navigatorZoom = -1;
+
+  var panel = null;
+  var panelX = 0;
+  var panelImage = null;
+  var panelImageOnLoad = function() {};
+  var panelImageWidth = 0;
+  var panelImageOffsetX = 0;
+  var panelLocator = null;
+  var panelLocatorTag = null;
+  var panelWidth = 0;
+  var panelMaxWidth = 0;
+
+  var playSamples = false;
+  var playDelay = 2000;
+
+//  alert("ChromosomeExplorer()...");
   /************************************************************************
    * Methods for setting up chip types, samples, zooms, and sets
    ************************************************************************/ 
@@ -14,7 +42,7 @@ function ChromosomeExplorer() {
       var s = 'Chip types: ';
       for (var kk=0; kk < chipTypes.length; kk++) {
         var chipType = chipTypes[kk];
-        s = s + '[<span id="chipType' + chipType + '"><a href="javascript:changeChipType(\'' + chipType + '\');">' + chipType + '</a></span>]'; 
+        s = s + '[<span id="chipType' + chipType + '"><a href="javascript:explorer.setChipType(\'' + chipType + '\');">' + chipType + '</a></span>]'; 
       }
       s = s + '<br>';
       updateLabel('chipTypeLabel', s);
@@ -31,7 +59,7 @@ function ChromosomeExplorer() {
         var name = sample;
         if (this.sampleAliases != null)
           name = this.sampleAliases[kk];
-        s = s + '[<span id="sample' + sample + '"><a href="javascript:changeSample(' + kk + ');">' + name + '</a></span>]<span style="font-size:1%"> </span>';
+        s = s + '[<span id="sample' + sample + '"><a href="javascript:explorer.setSample(' + kk + ');">' + name + '</a></span>]<span style="font-size:1%"> </span>';
       }
       s = s + ' ';
       updateLabel('samplesLabel', s);
@@ -60,7 +88,7 @@ function ChromosomeExplorer() {
     var s = 'Zoom: ';
     for (var kk=0; kk < scales.length; kk++) {
       var scale = scales[kk];
-      s = s + '[<span id="zoom' + scale + '"><a href="javascript:changeZoom(' + kk + ');">x' + padWidthZeros(scale, zWidth) + '</a></span>]'; 
+      s = s + '[<span id="zoom' + scale + '"><a href="javascript:explorer.setScale(' + kk + ');">x' + padWidthZeros(scale, zWidth) + '</a></span>]'; 
     }
     updateLabel('zoomLabel', s);
 
@@ -74,7 +102,7 @@ function ChromosomeExplorer() {
     var s = 'Sets: ';
     for (var kk=0; kk < sets.length; kk++) {
       var set = sets[kk];
-      s = s + '[<span id="set' + set + '"><a href="javascript:changeSet(' + kk + ');">' + set + '</a></span>]'; 
+      s = s + '[<span id="set' + set + '"><a href="javascript:explorer.setSet(' + kk + ');">' + set + '</a></span>]'; 
     }
     updateLabel('setLabel', s);
 
@@ -85,6 +113,29 @@ function ChromosomeExplorer() {
   }
 
 
+  this.setChromosomes = function(chromosomes) {
+    this.chromosomes = chromosomes;
+
+    if (chromosomes.length > 1) {
+      var s = '';
+      for (var kk=0; kk < chromosomes.length; kk++) {
+        var chr = chromosomes[kk];
+        var chrLabel = chr;
+        if (chr == 'X') {
+          chrLabel = "23(X)";
+        } else if (chr == 'Y') {
+          chrLabel = "24(Y)";
+        }
+        if (chrLabel != '') {
+            s = s + '[<span id="chromosome' + chr + '"><a href="javascript:explorer.setChromosome(' + kk + ');">' + chrLabel + '</a></span>]';
+        }
+      }
+      s = s + '<br>';
+      updateLabel('chromosomes', s);
+    }
+  }
+
+
   /************************************************************************
    * Methods for updating the display
    ************************************************************************/ 
@@ -441,11 +492,10 @@ function ChromosomeExplorer() {
      *******************************************************/
     nav = document.getElementById('navigator');
     navImage = document.getElementById('navigatorImage');
-  
     navArea = document.getElementById('navigatorArea');
     var mouseX = 0;
     var mouseDown = false;
-  
+
     /* Immitate onmousepress, which does not exists */
     navImage.onmousepress = function() {
       if (mouseDown) {
@@ -530,7 +580,6 @@ function ChromosomeExplorer() {
   
     this.set = this.sets[this.setIdx];
     highlightById('set' + this.set);
-
     if (this.chromosome == null)
       this.chromosome = this.chromosomes[this.chromosomeIdx];
     highlightById('chromosome' + this.chromosome);
@@ -541,12 +590,12 @@ function ChromosomeExplorer() {
     if (navigatorZoom == -1) {
       navigatorZoom = this.scale;
     }
-  
+
     this.imageUrl = document.getElementById('imageUrl');
     this.bookmarkUrl = document.getElementById('bookmarkUrl');
     this.cnrUrl = document.getElementById('cnrUrl');
 
-		this.setupEventHandlers();
+    this.setupEventHandlers();
   
     this.updateNavigator();
     this.updatePanel();
@@ -609,7 +658,7 @@ function ChromosomeExplorer() {
         owner.loadCount = 0;
         owner.setStatus("");
       }
-			panelImageOnLoad();
+      panelImageOnLoad();
       panelImageOnLoad = function() {};
     }
     panelImage.src = pathname;
@@ -654,11 +703,52 @@ function ChromosomeExplorer() {
   }
          
   this.onLoad = function() { }
+
+  this.gotoNextSample = function(step) {
+    var samples = this.samples;
+    var nextSampleIdx = this.sampleIdx + step;
+    if (nextSampleIdx >= samples.length) {
+      nextSampleIdx = 0;
+    } else if (nextSampleIdx < 0) {
+      nextSampleIdx = samples.length-1;
+    }
+    this.setSample(nextSampleIdx);
+    if (playSamples) {
+      cmd = "explorer.gotoNextSample(" + step + ");";
+      setTimeout(cmd, playDelay);
+    }
+  }
+
+  this.playAlongSamples = function(cmd) {
+    if (cmd == "start") {
+      playSamples = true;
+      this.gotoNextSample(+1);
+    } else if (cmd == "stop") {
+      playSamples = false;
+    }
+  }
+
+  this.playSlower = function() {
+    playDelay = playDelay * 2;
+  }
+
+  this.playFaster = function() {
+    playDelay = playDelay / 2;
+  }
+
+//  alert("ChromosomeExplorer()...ok");
 } /* ChromosomeExplorer */
 
 
 /****************************************************************
  HISTORY:
+ 2012-02-04
+ o Added playSlower() and playFaster().
+ o Moved gotoNextSample() and playAlongSamples() to 
+   ChromosomeExplorer.
+ o Now declaring private variables.
+ 2012-02-01
+ o Added setChromosomes().
  2008-07-30
  o Seems to work with Firefox 3.01.  Don't know about Firefox 2.
  2007-09-04
@@ -670,3 +760,5 @@ function ChromosomeExplorer() {
  o Created from old ChromosomeExplorer.js making it more of the
    style of class ArrayExplorer.
  ****************************************************************/
+
+// alert("ChromosomeExplorer...done");
